import React, { useEffect } from 'react';
import { useLocation, useNavigate } from 'react-router-dom';
import { useSelector } from 'react-redux';

/**
 * 导航守卫组件，用于在执行某些操作时防止用户离开页面
 */
const NavigationGuard = () => {
    const location = useLocation();
    const navigate = useNavigate();
    const isUploading = useSelector((state) => state.upload.isUploading);
    const previousLocation = React.useRef(location);

    // 检查是否在知识库详情页面
    const isInKnowledgeBaseDetail =
        location.pathname.includes('/knowledge-base/') && !location.pathname.endsWith('/knowledge-base/');

    useEffect(() => {
        // 如果不是导航到知识库详情页，且当前正在上传文件，且之前在知识库详情页
        if (!isInKnowledgeBaseDetail && isUploading && previousLocation.current.pathname.includes('/knowledge-base/')) {
            // 询问用户是否确认离开
            const confirmLeave = window.confirm('正在上传文件，离开页面可能会中断上传。确定要离开吗？');

            // 如果用户不确认，就回到之前的页面
            if (!confirmLeave) {
                navigate(previousLocation.current.pathname);
            }
        }

        // 更新前一个位置
        previousLocation.current = location;
    }, [location, isUploading]);

    return null; // 这个组件不渲染任何UI
};

export default NavigationGuard;
