import React, { useState } from 'react';
import SvgIcon from './SvgIcon';

/**
 * 资源列表组件 - 显示聊天回复中引用的资源
 * @param {Object} props - 组件属性
 * @param {Array} props.resources - 资源列表
 */
const ResourceList = ({ resources = [] }) => {
    const [expanded, setExpanded] = useState(false);

    if (!resources || resources.length === 0) {
        return null;
    }

    // 最多显示3个资源，超过3个时折叠
    const visibleResources = expanded ? resources : resources.slice(0, 3);
    const hasMore = resources.length > 3;

    return (
        <div className='resource-list mt-3 border-top pt-3'>
            <div className='d-flex align-items-center mb-2'>
                <span className='text-muted me-2' style={{ fontSize: '0.9rem' }}>
                    资源引用
                </span>
                <span className='badge bg-light text-dark'>{resources.length}</span>
            </div>
            <div className='resource-items'>
                {visibleResources.map((resource, index) => (
                    <div
                        key={index}
                        className='resource-item p-2 border rounded mb-2 d-flex align-items-center'
                        style={{ background: '#f8f9fa' }}
                    >
                        <div className='resource-icon me-2'>
                            <span className='badge bg-secondary me-1'>{(resource.similarity * 100).toFixed(0)}%</span>
                        </div>
                        <div className='resource-content flex-grow-1'>
                            <div className='resource-title fw-medium'>{resource.document_name}</div>
                            <div className='resource-source text-muted small'>{resource.dataset_name}</div>
                        </div>
                    </div>
                ))}

                {hasMore && !expanded && (
                    <button
                        className='btn btn-sm btn-light d-flex align-items-center'
                        onClick={() => setExpanded(true)}
                    >
                        <span className='me-1'>查看更多</span>
                        <SvgIcon className='chevron-down' width='14' height='14' />
                    </button>
                )}

                {expanded && (
                    <button
                        className='btn btn-sm btn-light d-flex align-items-center'
                        onClick={() => setExpanded(false)}
                    >
                        <span className='me-1'>收起</span>
                        <SvgIcon className='chevron-up' width='14' height='14' />
                    </button>
                )}
            </div>
        </div>
    );
};

export default ResourceList;
