import { combineReducers, configureStore } from '@reduxjs/toolkit';
import { persistReducer, persistStore } from 'redux-persist';
import sessionStorage from 'redux-persist/lib/storage/session';
import notificationReducer from './notification.slice.js';
import authReducer from './auth/auth.slice.js';
import knowledgeBaseReducer from './knowledgeBase/knowledgeBase.slice.js';
import chatReducer from './chat/chat.slice.js';
import permissionsReducer from './permissions/permissions.slice.js';
import notificationCenterReducer from './notificationCenter/notificationCenter.slice.js';
import uploadReducer from './upload/upload.slice.js';

const rootRducer = combineReducers({
    auth: authReducer,
    notification: notificationReducer,
    knowledgeBase: knowledgeBaseReducer,
    chat: chatReducer,
    permissions: permissionsReducer,
    notificationCenter: notificationCenterReducer,
    upload: uploadReducer,
});

const persistConfig = {
    key: 'root',
    storage: sessionStorage,
    whitelist: ['auth'],
};

// Persist configuration
const persistedReducer = persistReducer(persistConfig, rootRducer);

// Create the store with middleware
const store = configureStore({
    reducer: persistedReducer,
    middleware: (getDefaultMiddleware) =>
        getDefaultMiddleware({
            serializableCheck: {
                // Ignore these action types
                ignoredActions: ['persist/PERSIST'],
                // Ignore these field paths in all actions
                ignoredActionPaths: ['meta.arg', 'payload.timestamp'],
                // Ignore these paths in the state
                ignoredPaths: ['items.dates'],
            },
        }),
    devTools: process.env.NODE_ENV !== 'production',
});

// Create the persistor to manage rehydrating the store
export const persistor = persistStore(store);

export default store;
